==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/parser/sql/statement/core/src/main/java/org/apache/shardingsphere/sql/parser/statement/core/segment/dml/expr/InExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sql.parser.statement.core.segment.dml.expr;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;

import java.util.Collection;
import java.util.LinkedList;

/**
 * In expression.
 */
@RequiredArgsConstructor
@Getter
@Setter
public final class InExpression implements ExpressionSegment {
    
    private final int startIndex;
    
    private final int stopIndex;
    
    private final ExpressionSegment left;
    
    private final ExpressionSegment right;
    
    private final boolean not;
    
    /**
     * Get expression list from right.
     *
     * @return expression list.
     */
    public Collection<ExpressionSegment> getExpressionList() {
        Collection<ExpressionSegment> result = new LinkedList<>();
        if (right instanceof ListExpression) {
            result.addAll(((ListExpression) right).getItems());
        } else {
            result.add(this);
        }
        return result;
    }
    
    @Override
    public String getText() {
        return left.getText() + right.getText();
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/parser/sql/statement/core/src/main/java/org/apache/shardingsphere/sql/parser/statement/core/segment/dml/expr/InExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sql.parser.statement.core.segment.dml.expr;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;

import java.util.Collection;
import java.util.LinkedList;

/**
 * In expression.
 */
@RequiredArgsConstructor
@Getter
@Setter
public final class InExpression implements ExpressionSegment {
    
    private final int startIndex;
    
    private final int stopIndex;
    
    private final ExpressionSegment left;
    
    private final ExpressionSegment right;
    
    private final boolean not;
    
    /**
     * Get expression list from right.
     *
     * @return expression list.
     */
    public Collection<ExpressionSegment> getExpressionList() {
        Collection<ExpressionSegment> result = new LinkedList<>();
        if (right instanceof ListExpression) {
            result.addAll(((ListExpression) right).getItems());
        } else {
            result.add(this);
        }
        return result;
    }
    
    @Override
    public String getText() {
        String operator = not ? " NOT IN " : " IN ";
        return left.getText() + operator + right.getText();
    }
}
